@@ -21,13 +21,18 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // own
 #include "../x11locker.h"
 // Qt
-#include <QtTest>
 #include <QWindow>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
+#include <QtTest>
 // xcb
 #include <xcb/xcb.h>
 
-template <typename T> using ScopedCPointer = QScopedPointer<T, QScopedPointerPodDeleter>;
+template<typename T>
+using ScopedCPointer = QScopedPointer<T, QScopedPointerPodDeleter>;
 
 class LockWindowTest : public QObject
 {
@@ -41,9 +46,7 @@ private Q_SLOTS:
 xcb_screen_t *defaultScreen()
 {
     int screen = QX11Info::appScreen();
-    for (xcb_screen_iterator_t it = xcb_setup_roots_iterator(xcb_get_setup(QX11Info::connection()));
-            it.rem;
-            --screen, xcb_screen_next(&it)) {
+    for (xcb_screen_iterator_t it = xcb_setup_roots_iterator(xcb_get_setup(QX11Info::connection())); it.rem; --screen, xcb_screen_next(&it)) {
         if (screen == 0) {
             return it.data;
         }
@@ -54,16 +57,14 @@ xcb_screen_t *defaultScreen()
 bool isColored(const QColor color, const int x, const int y, const int width, const int height)
 {
     xcb_connection_t *c = QX11Info::connection();
-    const auto cookie = xcb_get_image(c, XCB_IMAGE_FORMAT_Z_PIXMAP, QX11Info::appRootWindow(),
-                                      x, y, width, height, ~0);
+    const auto cookie = xcb_get_image(c, XCB_IMAGE_FORMAT_Z_PIXMAP, QX11Info::appRootWindow(), x, y, width, height, ~0);
     ScopedCPointer<xcb_get_image_reply_t> xImage(xcb_get_image_reply(c, cookie, nullptr));
     if (xImage.isNull()) {
         return false;
     }
 
     // this operates on the assumption that X server default depth matches Qt's image format
-    QImage image(xcb_get_image_data(xImage.data()), width, height,
-                 xcb_get_image_data_length(xImage.data()) / height, QImage::Format_ARGB32_Premultiplied);
+    QImage image(xcb_get_image_data(xImage.data()), width, height, xcb_get_image_data_length(xImage.data()) / height, QImage::Format_ARGB32_Premultiplied);
 
     for (int i = 0; i < image.width(); i++) {
         for (int j = 0; j < image.height(); j++) {
@@ -166,7 +167,7 @@ void LockWindowTest::testBlankScreen()
     widgetWindow.setAutoFillBackground(true);
     widgetWindow.setPalette(p1);
     widgetWindow.show();
-    const uint32_t values[] = { XCB_STACK_MODE_ABOVE };
+    const uint32_t values[] = {XCB_STACK_MODE_ABOVE};
     xcb_configure_window(c, widgetWindow.winId(), XCB_CONFIG_WINDOW_STACK_MODE, values);
     xcb_flush(c);
     QTest::qWait(1000);
@@ -177,7 +178,6 @@ void LockWindowTest::testBlankScreen()
 
 void LockWindowTest::testEmergencyShow()
 {
-
     QWidget dummy;
     dummy.setWindowFlags(Qt::X11BypassWindowManagerHint);
     QPalette p;
@@ -228,15 +228,13 @@ void LockWindowTest::testEmergencyShow()
     const int width = screen->width_in_pixels;
     const int height = screen->height_in_pixels;
 
-    const auto cookie = xcb_get_image(c, XCB_IMAGE_FORMAT_Z_PIXMAP, QX11Info::appRootWindow(),
-                                      0, 0, width, height, ~0);
+    const auto cookie = xcb_get_image(c, XCB_IMAGE_FORMAT_Z_PIXMAP, QX11Info::appRootWindow(), 0, 0, width, height, ~0);
     ScopedCPointer<xcb_get_image_reply_t> xImage(xcb_get_image_reply(c, cookie, nullptr));
 
     QVERIFY(!xImage.isNull());
 
     // this operates on the assumption that X server default depth matches Qt's image format
-    QImage image(xcb_get_image_data(xImage.data()), width, height,
-                 xcb_get_image_data_length(xImage.data()) / height, QImage::Format_ARGB32_Premultiplied);
+    QImage image(xcb_get_image_data(xImage.data()), width, height, xcb_get_image_data_length(xImage.data()) / height, QImage::Format_ARGB32_Premultiplied);
 
     bool isColored = false;
     int blackPixelCount = 0;
