@@ -26,8 +26,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // KDE
 // Qt
 #include <QApplication>
+#include <QScreen>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QDesktopWidget>
 #include <QX11Info>
+#endif
 // X11
 #include <X11/Xatom.h>
 #include <xcb/xcb.h>
@@ -85,8 +90,17 @@ void X11Locker::initialize()
         }
         XFree(real);
     }
-    connect(QApplication::desktop(), &QDesktopWidget::resized, this, &X11Locker::updateGeo);
-    connect(QApplication::desktop(), &QDesktopWidget::screenCountChanged, this, &X11Locker::updateGeo);
+
+    // monitor for screen geometry changes
+    connect(qGuiApp, &QGuiApplication::screenAdded, this, [this](QScreen *screen) {
+        connect(screen, &QScreen::geometryChanged, this, &X11Locker::updateGeo);
+        updateGeo();
+    });
+    connect(qGuiApp, &QGuiApplication::screenRemoved, this, &X11Locker::updateGeo);
+    const auto screens = QGuiApplication::screens();
+    for (auto *screen : screens) {
+        connect(screen, &QScreen::geometryChanged, this, &X11Locker::updateGeo);
+    }
 }
 
 void X11Locker::showLockWindow()
@@ -275,7 +289,11 @@ void sendEvent(xcb_generic_event_t *event, xcb_window_t target, int x, int y)
     xcb_send_event(QX11Info::connection(), false, target, XCB_EVENT_MASK_NO_EVENT, reinterpret_cast<const char *>(&e));
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 bool X11Locker::nativeEventFilter(const QByteArray &eventType, void *message, long int *)
+#else
+bool X11Locker::nativeEventFilter(const QByteArray &eventType, void *message, qintptr *)
+#endif
 {
     if (eventType != QByteArrayLiteral("xcb_generic_event_t")) {
         return false;
@@ -517,8 +535,12 @@ void X11Locker::stayOnTop()
 
 void X11Locker::updateGeo()
 {
-    QDesktopWidget *desktop = QApplication::desktop();
-    m_background->setGeometry(desktop->geometry());
+    QRect geometry;
+    const auto screens = QGuiApplication::screens();
+    for (auto *screen : screens) {
+        geometry |= screen->geometry();
+    }
+    m_background->setGeometry(geometry);
     m_background->update();
 }
 
